@@ -219,7 +219,10 @@ def local_score(data, cols, score_function='default', weights=None, alpha=0.3):
         if score_function == 'default':
             score_function = 'bic' if 'int' in data.dtype.name else 'bic_g'
         try:
-            ls = globals()[score_function](data, np.asarray(cols), weights, alpha=alpha)
+            if score_function == 'nal':
+                ls = globals()[score_function](data, np.asarray(cols), weights, alpha=alpha)
+            else:
+                ls = globals()[score_function](data, np.asarray(cols), weights)
         except Exception as e:
             raise Exception('score function ' + str(
                 e) + ' is undefined or does not fit to data type. Available score functions are: bic (BIC for discrete variables) and nal (NAL for discrete variables).')
