@@ -323,7 +323,7 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                         par_sea = tuple(sorted(dag[vj]['par'] + [vi]))
                         if par_sea not in cache[vj]:
                             cols = [varnames.index(x) for x in (vj,) + par_sea]
-                            cache[vj][par_sea] = local_score(data, cols, score_function, alpha)
+                            cache[vj][par_sea] = local_score(data, cols, score_function, alpha=alpha)
                         time_score += time.time() - start_time
                         diff_temp = cache[vj][par_sea] - cache[vj][tuple(dag[vj]['par'])]
                         if debug:
@@ -343,11 +343,11 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                         par_sea_par_vi = tuple(sorted(dag[par_vi]['par'] + [vi]))
                         if par_sea_par_vi not in cache[par_vi]:
                             cols = [varnames.index(x) for x in (par_vi,) + par_sea_par_vi]
-                            cache[par_vi][par_sea_par_vi] = local_score(data, cols, score_function, alpha)
+                            cache[par_vi][par_sea_par_vi] = local_score(data, cols, score_function, alpha=alpha)
                         par_sea_vi = tuple([x for x in dag[vi]['par'] if x != par_vi])
                         if par_sea_vi not in cache[vi]:
                             cols = [varnames.index(x) for x in (vi,) + par_sea_vi]
-                            cache[vi][par_sea_vi] = local_score(data, cols, score_function, alpha)
+                            cache[vi][par_sea_vi] = local_score(data, cols, score_function, alpha=alpha)
                         time_score += time.time() - start_time
                         diff_temp = cache[par_vi][par_sea_par_vi] + cache[vi][par_sea_vi] - cache[par_vi][
                             tuple(dag[par_vi]['par'])] - cache[vi][tuple(dag[vi]['par'])]
@@ -363,7 +363,7 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                     par_sea = tuple([x for x in dag[vi]['par'] if x != par_vi])
                     if par_sea not in cache[vi]:
                         cols = [varnames.index(x) for x in (vi,) + par_sea]
-                        cache[vi][par_sea] = local_score(data, cols, score_function, alpha)
+                        cache[vi][par_sea] = local_score(data, cols, score_function, alpha=alpha)
                     time_score += time.time() - start_time
                     diff_temp = cache[vi][par_sea] - cache[vi][tuple(dag[vi]['par'])]
                     if diff_temp - diff > 1e-10:
@@ -634,11 +634,11 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
 
                             if parents_new not in cache[y]:
                                 cols = [varnames.index(v) for v in (y,) + parents_new]
-                                cache[y][parents_new] = local_score(data, cols, score_function, alpha)
+                                cache[y][parents_new] = local_score(data, cols, score_function, alpha=alpha)
                             score_new = cache[y][parents_new]
                             if parents_cur not in cache[y]:
                                 cols = [varnames.index(v) for v in (y,) + parents_cur]
-                                cache[y][parents_cur] = local_score(data, cols, score_function, alpha)
+                                cache[y][parents_cur] = local_score(data, cols, score_function, alpha=alpha)
                             score_cur = cache[y][parents_cur]
                             diff_temp = score_new - score_cur
                             if diff_temp > diff:
@@ -681,11 +681,11 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
 
                             if parents_new not in cache[y]:
                                 cols = [varnames.index(v) for v in (y,) + parents_new]
-                                cache[y][parents_new] = local_score(data, cols, score_function, alpha)
+                                cache[y][parents_new] = local_score(data, cols, score_function, alpha=alpha)
                             score_new = cache[y][parents_new]
                             if parents_cur not in cache[y]:
                                 cols = [varnames.index(v) for v in (y,) + parents_cur]
-                                cache[y][parents_cur] = local_score(data, cols, score_function, alpha)
+                                cache[y][parents_cur] = local_score(data, cols, score_function, alpha=alpha)
                             score_cur = cache[y][parents_cur]
                             diff_temp = score_new - score_cur
                             if diff_temp > diff:
